# eric7.Plugins.VcsPlugins.vcsPySvn.SvnTagBranchListDialog

Module implementing a dialog to show a list of tags or branches.

### Global Attributes

None

### Classes

SvnTagBranchListDialog | Class implementing a dialog to show a list of tags or branches.

### Functions

None

## SvnTagBranchListDialog

Class implementing a dialog to show a list of tags or branches.

### Derived from

QDialog, SvnDialogMixin, Ui_SvnTagBranchListDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnTagBranchListDialog | Constructor
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a tag item in the taglist.
__resizeColumns | Private method to resize the list columns.
__resort | Private method to resort the tree.
__showError | Private slot to show an error message.
getTagList | Public method to get the taglist of the last run.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the svn status command.

### Static Methods

None

#### SvnTagBranchListDialog (Constructor)

SvnTagBranchListDialog(vcs, parent=None)

Constructor

vcs
  reference to the vcs object
parent
  parent widget (QWidget)

#### SvnTagBranchListDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### SvnTagBranchListDialog.__generateItem

__generateItem(revision, author, date, name)

Private method to generate a tag item in the taglist.

revision
  revision number (integer)
author
  author of the tag (string)
date
  date of the tag (string)
name
  name (path) of the tag (string)

#### SvnTagBranchListDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### SvnTagBranchListDialog.__resort

__resort()

Private method to resort the tree.

#### SvnTagBranchListDialog.__showError

__showError(msg)

Private slot to show an error message.

msg
  error message to show (string)

#### SvnTagBranchListDialog.getTagList

getTagList()

Public method to get the taglist of the last run.

Return:
  list of tags (list of strings)

#### SvnTagBranchListDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

#### SvnTagBranchListDialog.start

start(path, tags=True)

Public slot to start the svn status command.

path
  name of directory to be listed (string)
tags
  flag indicating a list of tags is requested (False = branches, True = tags)

Return:
  flag indicating success (boolean)

Up